@@ -9,8 +9,11 @@
 # http://www.python.org/dev/peps/pep-0333/#the-server-gateway-side
 
 import os, sys
+from mercurial import util
 
 def launch(application):
+    util.set_binary(sys.stdin)
+    util.set_binary(sys.stdout)
 
     environ = dict(os.environ.items())
     environ['wsgi.input'] = sys.stdin
@@ -20,7 +23,7 @@ def launch(application):
     environ['wsgi.multiprocess'] = True
     environ['wsgi.run_once'] = True
 
-    if environ.get('HTTPS','off') in ('on','1'):
+    if environ.get('HTTPS','off').lower() in ('on','1','yes'):
         environ['wsgi.url_scheme'] = 'https'
     else:
         environ['wsgi.url_scheme'] = 'http'
